@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -34,9 +34,8 @@
 #include <Decoder.hpp>
 #include <Reader.hpp>
 
-#include <QCoreApplication>
+#include <QGuiApplication>
 #include <QVarLengthArray>
-#include <QInputDialog>
 #include <QMessageBox>
 #include <QRawFont>
 #include <QAction>
@@ -68,6 +67,14 @@ PlayClass::PlayClass() :
         zoom = 1.0;
     }
 
+    if (QMPlay2Core.getSettings().getBool("IntegerScaling"))
+    {
+        m_integerScaling = true;
+        fixZoomForIntegerScaling();
+    }
+
+    m_preciseZoom = QMPlay2Core.getSettings().getBool("PreciseZoom");
+
     speed = subtitlesScale = 1.0;
     flip = 0;
     rotate90 = spherical = false;
@@ -428,8 +435,21 @@ void PlayClass::messageAndOSD(const QString &txt, bool onStatusBar, double durat
 {
     if (ass && QMPlay2Core.getSettings().getBool("OSD/Enabled"))
     {
+        QByteArray txtData;
+        if (QGuiApplication::layoutDirection() == Qt::RightToLeft && txt.size() >= 2)
+        {
+            // libass puts "%" and "x" character to the right, so swap it
+            if (txt.at(txt.size() - 2).isDigit() && (txt.at(txt.size() - 1).isLetter() || txt.at(txt.size() - 1) == QChar('%')))
+            {
+                txtData = (txt.at(txt.size() - 1) + txt.mid(0, txt.size() - 1)).toUtf8();
+            }
+        }
+        if (txtData.isNull())
+        {
+            txtData = txt.toUtf8();
+        }
         osdMutex.lock();
-        ass->getOSD(osd, txt.toUtf8(), duration);
+        ass->getOSD(osd, txtData, duration);
         osdMutex.unlock();
     }
     if (onStatusBar)
@@ -460,6 +480,31 @@ void PlayClass::setRecording(bool checked)
         demuxThr->stopRecording();
 }
 
+void PlayClass::setIntegerScaling(bool integerScaling)
+{
+    m_integerScaling = integerScaling;
+
+    if (m_integerScaling)
+    {
+        fixZoomForIntegerScaling();
+    }
+
+    if (vThr)
+    {
+        applyZoom(false);
+    }
+
+    messageAndOSD(m_integerScaling ? tr("Integer scaling: enabled") : tr("Integer scaling: disabled"));
+
+    QMPlay2Core.getSettings().set("IntegerScaling", m_integerScaling);
+}
+
+void PlayClass::setPreciseZoom(bool preciseZoom)
+{
+    m_preciseZoom = preciseZoom;
+    QMPlay2Core.getSettings().set("PreciseZoom", m_preciseZoom);
+}
+
 inline bool PlayClass::hasVideoStream()
 {
     return vThr && demuxThr && demuxThr->demuxer && videoStream > -1;
@@ -469,6 +514,18 @@ inline bool PlayClass::hasAudioStream()
     return aThr && demuxThr && demuxThr->demuxer && audioStream > -1;
 }
 
+double PlayClass::getZoom() const
+{
+    if (!m_integerScaling)
+        return zoom;
+
+    const qreal dpr = QMPlay2Core.getVideoDevicePixelRatio();
+    return zoom * std::max(
+        m_videoSize.width()  / (m_videoWinSize.width()  * dpr),
+        m_videoSize.height() / (m_videoWinSize.height() * dpr)
+    );
+}
+
 void PlayClass::speedMessageAndOSD()
 {
     messageAndOSD(tr("Play speed") + QString(": %1x").arg(speed));
@@ -672,6 +729,53 @@ void PlayClass::loadAssFonts(const QList<StreamInfo *> &streams)
     }
 }
 
+void PlayClass::applyZoom(bool message)
+{
+    Q_ASSERT(vThr);
+    if (ass)
+    {
+        ass->setZoom(getZoom());
+    }
+    if (message)
+    {
+        const auto text = tr("Zoom: %1");
+        if (m_integerScaling && zoom < 1.0)
+        {
+            const auto zoomRational = av_d2q(zoom, 10);
+            messageAndOSD(text.arg(QStringLiteral("%1/%2").arg(zoomRational.num).arg(zoomRational.den)));
+        }
+        else if (m_integerScaling)
+        {
+            messageAndOSD(text.arg(zoom));
+        }
+        else
+        {
+            messageAndOSD(text.arg(zoom, 0, 'f', (qRound(zoom * 1000.0) % 10 > 0) ? 3 : 2));
+        }
+    }
+    vThr->setZoom(getZoom());
+    vThr->processParams();
+}
+
+void PlayClass::fixZoomForIntegerScaling()
+{
+    Q_ASSERT(m_integerScaling);
+    if (zoom != 1.0)
+    {
+        bool inv = false;
+        if (zoom < 1.0)
+        {
+            zoom = 1.0 / zoom;
+            inv = true;
+        }
+        zoom = qRound(zoom);
+        if (inv)
+        {
+            zoom = 1.0 / zoom;
+        }
+    }
+}
+
 inline void PlayClass::emitSetVideoCheckState()
 {
     emit setVideoCheckState(rotate90, flip & Qt::Horizontal, flip & Qt::Vertical, spherical);
@@ -748,11 +852,18 @@ void PlayClass::settingsChanged(int page, bool forceRestart, bool initFilters)
     if (initFilters && vThr && !restarted)
         vThr->initFilters();
 }
-void PlayClass::videoResized(int w, int h)
+void PlayClass::videoResized(const QSize &size)
 {
-    if (ass && (w != videoWinW || h != videoWinH))
+    if (m_videoWinSize == size)
+        return;
+
+    m_videoWinSize = size;
+
+    if (ass)
     {
-        ass->setWindowSize(w, h);
+        ass->setWindowSize(size);
+        if (m_integerScaling)
+            ass->setZoom(getZoom());
         if (QMPlay2Core.getSettings().getBool("OSD/Enabled"))
         {
             osdMutex.lock();
@@ -763,8 +874,12 @@ void PlayClass::videoResized(int w, int h)
         if (vThr)
             vThr->updateSubs();
     }
-    videoWinW = w;
-    videoWinH = h;
+
+    if (m_integerScaling && vThr)
+    {
+        vThr->setZoom(getZoom());
+        vThr->processParams();
+    }
 }
 
 void PlayClass::videoAdjustmentChanged(const QString &osdText)
@@ -812,51 +927,96 @@ void PlayClass::slowDown()
 }
 void PlayClass::setSpeed()
 {
-    bool ok;
-    double s = QInputDialog::getDouble(nullptr, tr("Play speed"), tr("Set playback speed"), speed, 0.05, 100.0, 3, &ok);
-    if (ok)
-    {
-        speed = s;
-        speedMessageAndOSD();
-    }
+    Functions::getUserDoubleValue(
+        QMPlay2GUI.mainW,
+        tr("Play speed"),
+        tr("Set playback speed"),
+        speed,
+        0.05,
+        100.0,
+        3,
+        0.001,
+        [this](double s) {
+            if (!qFuzzyCompare(speed, s))
+            {
+                speed = s;
+                speedMessageAndOSD();
+            }
+        }
+    );
 }
 void PlayClass::zoomIn()
 {
     if (vThr)
     {
-        zoom += 0.05;
-        if (ass)
-            ass->setZoom(zoom);
-        messageAndOSD("Zoom: " + QString::number(zoom));
-        vThr->setZoom();
-        vThr->processParams();
+        if (m_integerScaling)
+        {
+            if (zoom >= 1.0)
+                zoom += 1.0;
+            else
+                zoom = 1.0 / ((1.0 / zoom) - 1.0);
+        }
+        else
+        {
+            if (m_preciseZoom)
+                zoom += 0.01;
+            else
+                zoom += 0.05;
+        }
+        applyZoom(true);
     }
 }
 void PlayClass::zoomOut()
 {
-    if (vThr && zoom - 0.05 > 0.0)
+    if (vThr && zoom - (m_integerScaling ? 0.2 : 0.05) > 0.0)
     {
-        zoom -= 0.05;
-        if (ass)
-            ass->setZoom(zoom);
-        messageAndOSD("Zoom: " + QString::number(zoom));
-        vThr->setZoom();
-        vThr->processParams();
+        if (m_integerScaling)
+        {
+            if (zoom > 1.0)
+                zoom -= 1.0;
+            else
+                zoom = 1.0 / ((1.0 / zoom) + 1.0);
+        }
+        else
+        {
+            if (m_preciseZoom)
+                zoom -= 0.01;
+            else
+                zoom -= 0.05;
+            if (zoom < 0.05)
+                zoom = 0.05;
+        }
+        applyZoom(true);
     }
 }
+void PlayClass::setZoom()
+{
+    Functions::getUserDoubleValue(
+        QMPlay2GUI.mainW,
+        tr("Zoom"),
+        tr("Set zoom"),
+        zoom,
+        0.05,
+        20.0,
+        3,
+        0.001,
+        [this](double z) {
+            if (!qFuzzyCompare(zoom, z))
+            {
+                zoom = z;
+                if (vThr)
+                    applyZoom(true);
+            }
+        }
+    );
+}
 void PlayClass::zoomReset()
 {
     if (zoom != 1.0)
     {
         zoom = 1.0;
         if (vThr)
-        {
-            if (ass)
-                ass->setZoom(zoom);
-            messageAndOSD("Zoom: " + QString::number(zoom));
-            vThr->setZoom();
-            vThr->processParams();
-        }
+            applyZoom(true);
     }
 }
 void PlayClass::otherReset()
@@ -869,19 +1029,78 @@ void PlayClass::otherReset()
 }
 void PlayClass::aRatio()
 {
-    aRatioName = sender()->objectName();
-    QString msg_txt = tr("Aspect ratio") + ": " + ((QAction *)sender())->text().remove('&');
-    if (hasVideoStream())
+    auto sender = qobject_cast<QAction *>(this->sender());
+    Q_ASSERT(sender);
+    bool custom = false;
+    aRatioName = sender->objectName();
+    auto setARatio = [&] {
+        QString msgTxt = tr("Aspect ratio") + ": " + sender->text().remove('&');
+        if (custom)
+        {
+            msgTxt += QStringLiteral(" (%1)").arg(aRatioName);
+        }
+        if (hasVideoStream())
+        {
+            const double aspectRatio = getARatio();
+            if (ass)
+                ass->setARatio(aspectRatio);
+            messageAndOSD(msgTxt);
+            vThr->setARatio(aspectRatio, getSAR());
+            vThr->processParams();
+        }
+        else
+        {
+            messageAndOSD(msgTxt);
+        }
+    };
+    if (aRatioName.startsWith(QStringLiteral("custom:")))
     {
-        const double aspect_ratio = getARatio();
-        if (ass)
-            ass->setARatio(aspect_ratio);
-        messageAndOSD(msg_txt);
-        vThr->setARatio(aspect_ratio, getSAR());
-        vThr->processParams();
+        constexpr double min = 0.5;
+        constexpr double max = 3.0;
+        double value = qBound(min, aRatioName.right(aRatioName.size() - 7).toDouble(), max);
+        auto setCustomARatio = [&] {
+            aRatioName = QString::number(value);
+            custom = true;
+            setARatio();
+        };
+        if (sender->property("SkipDialog").toBool())
+        {
+            sender->setProperty("SkipDialog", QVariant());
+            setCustomARatio();
+        }
+        else
+        {
+            bool first = true;
+            Functions::getUserDoubleValue(
+                QMPlay2GUI.mainW,
+                tr("Custom aspect ratio"),
+                tr("Set aspect ratio"),
+                value,
+                min,
+                max,
+                6,
+                0.001,
+                [&](double valueNew) {
+                    if (!qFuzzyCompare(value, valueNew))
+                    {
+                        value = valueNew;
+                        sender->setObjectName(QStringLiteral("custom:%1").arg(value));
+                        QMPlay2Core.getSettings().set("CustomAspectRatio", value);
+                        setCustomARatio();
+                    }
+                    else if (first)
+                    {
+                        setCustomARatio();
+                    }
+                    first = false;
+                }
+            );
+        }
     }
     else
-        messageAndOSD(msg_txt);
+    {
+        setARatio();
+    }
 }
 void PlayClass::volume(int l, int r)
 {
@@ -924,12 +1143,23 @@ void PlayClass::speedUpVideo()
 }
 void PlayClass::setVideoSync()
 {
-    bool ok;
-    double vs = QInputDialog::getDouble(nullptr, tr("Video delay"), tr("Set video delay (sec.)"), videoSync, -maxThreshold, maxThreshold, 1, &ok);
-    if (!ok)
-        return;
-    videoSync = vs;
-    messageAndOSD(tr("Video delay") + ": " + QString::number(videoSync) + "s");
+    Functions::getUserDoubleValue(
+        QMPlay2GUI.mainW,
+        tr("Video delay"),
+        tr("Set video delay (sec.)"),
+        videoSync,
+        -maxThreshold,
+        maxThreshold,
+        1,
+        0.1,
+        [this](double vs) {
+            if (!qFuzzyCompare(videoSync, vs))
+            {
+                videoSync = vs;
+                messageAndOSD(tr("Video delay") + ": " + QString::number(videoSync) + "s");
+            }
+        }
+    );
 }
 void PlayClass::slowDownSubs()
 {
@@ -953,12 +1183,25 @@ void PlayClass::setSubtitlesSync()
 {
     if (subtitlesStream == -1)
         return;
-    bool ok;
-    double ss = QInputDialog::getDouble(nullptr, tr("Subtitles delay"), tr("Set subtitles delay (sec.)"), subtitlesSync, fileSubs.isEmpty() ? 0 : -2147483647, 2147483647, 2, &ok);
-    if (!ok)
-        return;
-    subtitlesSync = ss;
-    messageAndOSD(tr("Subtitles delay") + ": " + QString::number(subtitlesSync) + "s");
+
+    Functions::getUserDoubleValue(
+        QMPlay2GUI.mainW,
+        tr("Subtitles delay"),
+        tr("Set subtitles delay (sec.)"),
+        subtitlesSync,
+        fileSubs.isEmpty()
+            ? 0.0
+            : -2147483647.0,
+        2147483647.0,
+        2,
+        0.01,
+        [this](double ss) {
+            if (!qFuzzyCompare(subtitlesSync, ss))
+            {
+                subtitlesSync = ss;
+                messageAndOSD(tr("Subtitles delay") + ": " + QString::number(subtitlesSync) + "s");
+            }
+    });
 }
 void PlayClass::biggerSubs()
 {
@@ -1120,7 +1363,9 @@ void PlayClass::frameSizeUpdated(int w, int h) //jeżeli rozmiar obrazu zmieni s
     }
     if (vThr) //"demuxThr->demuxer" can be closed, but "vThr" can be in waiting state
     {
-        vThr->setFrameSize(w, h);
+        m_videoSize = QSize(w, h);
+
+        vThr->setFrameSize(m_videoSize);
         vThr->initFilters();
         vThr->processParams();
         vThr->updateUnlock();
@@ -1326,7 +1571,24 @@ static Decoder *loadStream(
                 if (params->codec_type != type)
                     continue;
 
-                if (defaultStream < 0 && streams[i]->is_default)
+                switch (params->codec_id) // Skip codecs which are or which can be a still image (e.g. cover)
+                {
+                    case AV_CODEC_ID_MJPEG:
+                    case AV_CODEC_ID_MJPEGB:
+                    case AV_CODEC_ID_LJPEG:
+                    case AV_CODEC_ID_JPEGLS:
+                    case AV_CODEC_ID_GIF:
+                        continue;
+                    default:
+                        if (auto codec = avcodec_find_decoder(params->codec_id))
+                        {
+                            if (QByteArray::fromRawData(codec->long_name, qstrlen(codec->long_name)).contains(" image"))
+                                continue;
+                        }
+                        break;
+                }
+
+                if (defaultStream < 0 && streams[i]->is_default && !streams[i]->skip_auto_select)
                     defaultStream = i;
 
                 if (desiredVideoHeight > 0)
@@ -1357,7 +1619,7 @@ static Decoder *loadStream(
                     }
                 }
 
-                if (!lang.isEmpty() && chosenLangStream < 0)
+                if (!lang.isEmpty() && chosenLangStream < 0 && !streams[i]->skip_auto_select)
                 {
                     for (const QMPlay2Tag &tag : std::as_const(streams[i]->other_info))
                     {
@@ -1385,7 +1647,7 @@ static Decoder *loadStream(
                     continue;
 
                 StreamInfo &streamInfo = *streams[i];
-                if (streamInfo.params->codec_type == type && (defaultStream == -1 || i == defaultStream))
+                if (streamInfo.params->codec_type == type && ((defaultStream == -1 && !streamInfo.skip_auto_select) || i == defaultStream))
                 {
                     if (streamInfo.must_decode || !subtitles)
                         dec = Decoder::create(streamInfo, decoders, modNameOutput);
@@ -1460,11 +1722,14 @@ void PlayClass::load(Demuxer *demuxer)
                     emitSetVideoCheckState();
 
                 vThr->setDec(dec);
+                vThr->setTsDiscontPossible(streams[videoStream]->ts_discont_possible);
 
-                vThr->setFrameSize(streams[videoStream]->params->width, streams[videoStream]->params->height);
+                m_videoSize = QSize(streams[videoStream]->params->width, streams[videoStream]->params->height);
+
+                vThr->setFrameSize(m_videoSize);
                 vThr->setARatio(aspect_ratio, getSAR());
                 vThr->setVideoAdjustment();
-                vThr->setZoom();
+                vThr->setZoom(getZoom());
                 const bool hasSpherical = vThr->setSpherical();
                 const bool hasRotate90 = vThr->setRotate90();
                 vThr->setFlip();
@@ -1495,10 +1760,10 @@ void PlayClass::load(Demuxer *demuxer)
 
                     fps = streams[videoStream]->getFPS();
                     ass = new LibASS(QMPlay2Core.getSettings());
-                    ass->setWindowSize(videoWinW, videoWinH);
+                    ass->setWindowSize(m_videoWinSize);
                     ass->setFontScale(subtitlesScale);
                     ass->setARatio(aspect_ratio);
-                    ass->setZoom(zoom);
+                    ass->setZoom(getZoom());
                     ass->initOSD();
 
                     emit videoStarted(noVideo);
