@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -42,8 +42,12 @@ using namespace std;
 
 extern "C"
 {
-    #include <libavcodec/avcodec.h>
     #include <libavcodec/version.h>
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(58, 91, 100)
+    #include <libavcodec/bsf.h>
+#else
+    #include <libavcodec/avcodec.h>
+#endif
     #include <libavutil/pixdesc.h>
     #include <libswscale/swscale.h>
 }
@@ -161,10 +165,10 @@ int CuvidDec::videoSequence(CUVIDEOFORMAT *format)
         : cudaVideoSurfaceFormat_NV12
     ;
 
-    cuvidDecInfo.ulWidth = format->coded_width;
-    cuvidDecInfo.ulHeight = format->coded_height;
-    cuvidDecInfo.ulTargetWidth = cuvidDecInfo.ulWidth;
-    cuvidDecInfo.ulTargetHeight = cuvidDecInfo.ulHeight;
+    cuvidDecInfo.ulWidth = format->display_area.right;
+    cuvidDecInfo.ulHeight = format->display_area.bottom;
+    cuvidDecInfo.ulTargetWidth = format->coded_width;
+    cuvidDecInfo.ulTargetHeight = format->coded_height;
 
     cuvidDecInfo.target_rect.right = cuvidDecInfo.ulWidth;
     cuvidDecInfo.target_rect.bottom = cuvidDecInfo.ulHeight;
