@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -88,6 +88,8 @@ private:
     int threads, lowres;
     bool respectHurryUP, skipFrames, forceSkipFrames, thread_type_slice;
     int lastFrameW, lastFrameH, lastPixFmt;
+    int m_teletextPage = 0;
+    bool m_teletextTransparent = false;
     SwsContext *sws_ctx;
 
     const AVPixFmtDescriptor *m_origPixDesc = nullptr;
@@ -96,6 +98,8 @@ private:
 
     std::deque<Subtitle> m_subtitles;
 
+    double m_lastTs = qQNaN();
+
 #ifdef USE_VULKAN
     std::shared_ptr<QmVk::BufferPool> m_vkBufferPool;
     bool m_disableZeroCopy = false;
