@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2024 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #include "BufferView.hpp"
@@ -20,8 +20,7 @@ shared_ptr<BufferView> BufferView::create(
         buffer,
         format,
         offset,
-        range,
-        Priv()
+        range
     );
     bufferView->init();
     return bufferView;
@@ -31,8 +30,7 @@ BufferView::BufferView(
     const shared_ptr<Buffer> &buffer,
     vk::Format format,
     vk::DeviceSize offset,
-    vk::DeviceSize range,
-    Priv)
+    vk::DeviceSize range)
     : MemoryObjectBase(buffer->device())
     , m_buffer(buffer)
     , m_format(format)
@@ -52,7 +50,7 @@ void BufferView::init()
     bufferViewCreateInfo.format = m_format;
     bufferViewCreateInfo.offset = m_offset;
     bufferViewCreateInfo.range = m_range;
-    m_bufferView = m_device->createBufferViewUnique(bufferViewCreateInfo);
+    m_bufferView = m_device->createBufferViewUnique(bufferViewCreateInfo, nullptr, dld());
 }
 
 void BufferView::copyTo(
