@@ -1,14 +1,16 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2023 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
 
 #include "QmVkExport.hpp"
 
-#include <vulkan/vulkan.hpp>
+#include "DescriptorType.hpp"
+
+#include <memory>
 
 namespace QmVk {
 
@@ -18,19 +20,16 @@ class Device;
 
 class QMVK_EXPORT DescriptorSetLayout
 {
-    struct Priv {};
-
 public:
     static shared_ptr<DescriptorSetLayout> create(
         const shared_ptr<Device> &device,
-        const vector<vk::DescriptorPoolSize> &descriptorTypes
+        const vector<DescriptorType> &descriptorTypes
     );
 
 public:
     DescriptorSetLayout(
         const shared_ptr<Device> &device,
-        const vector<vk::DescriptorPoolSize> &descriptorTypes,
-        Priv
+        const vector<DescriptorType> &descriptorTypes
     );
     ~DescriptorSetLayout();
 
@@ -41,14 +40,14 @@ public:
     inline shared_ptr<Device> device() const;
 
     inline bool isEmpty() const;
-    inline const vector<vk::DescriptorPoolSize> &descriptorTypes() const;
+    inline const vector<DescriptorType> &descriptorTypes() const;
 
 public:
     inline operator const vk::DescriptorSetLayout *() const;
 
 private:
     const shared_ptr<Device> m_device;
-    const vector<vk::DescriptorPoolSize> m_descriptorTypes;
+    const vector<DescriptorType> m_descriptorTypes;
 
     vk::UniqueDescriptorSetLayout m_descriptorSetLayout;
 };
@@ -64,7 +63,7 @@ bool DescriptorSetLayout::isEmpty() const
 {
     return m_descriptorTypes.empty();
 }
-const vector<vk::DescriptorPoolSize> &DescriptorSetLayout::descriptorTypes() const
+const vector<DescriptorType> &DescriptorSetLayout::descriptorTypes() const
 {
     return m_descriptorTypes;
 }
