@@ -40,7 +40,7 @@ private:
 
 public:
     inline shared_ptr<PhysicalDevice> physicalDevice() const;
-    inline const vk::DispatchLoaderDynamic &dld() const;
+    inline const vk::detail::DispatchLoaderDynamic &dld() const;
 
     inline const auto &enabledExtensions() const;
     inline bool hasExtension(const char *extensionName) const;
@@ -59,7 +59,7 @@ public:
 
 private:
     const shared_ptr<PhysicalDevice> m_physicalDevice;
-    const vk::DispatchLoaderDynamic &m_dld;
+    const vk::detail::DispatchLoaderDynamic &m_dld;
 
     unordered_set<string> m_enabledExtensions;
     bool m_hasYcbcr = false;
@@ -77,7 +77,7 @@ shared_ptr<PhysicalDevice> Device::physicalDevice() const
 {
     return m_physicalDevice;
 }
-const vk::DispatchLoaderDynamic &Device::dld() const
+const vk::detail::DispatchLoaderDynamic &Device::dld() const
 {
     return m_dld;
 }
