@@ -1,7 +1,7 @@
 ﻿// SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2024 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -120,7 +120,7 @@ public:
 private:
     Type m_type;
     Access m_access;
-    vector<shared_ptr<MemoryObjectBase>> m_objects;
+    vector<weak_ptr<MemoryObjectBase>> m_objects;
 
 #ifndef QMVK_NO_GRAPHICS
     // Image
