@@ -27,7 +27,6 @@ class Device;
 class QMVK_EXPORT PhysicalDevice : public vk::PhysicalDevice, public enable_shared_from_this<PhysicalDevice>
 {
     friend class AbstractInstance;
-    struct Priv {};
 
 public:
     using MemoryType = pair<uint32_t, vk::MemoryPropertyFlags>;
@@ -53,8 +52,7 @@ public:
 public:
     PhysicalDevice(
         const shared_ptr<AbstractInstance> &instance,
-        vk::PhysicalDevice physicalDevice,
-        Priv
+        vk::PhysicalDevice physicalDevice
     );
     ~PhysicalDevice();
 
@@ -98,7 +96,7 @@ public:
     );
 
     inline shared_ptr<AbstractInstance> instance() const;
-    inline const vk::DispatchLoaderDynamic &dld() const;
+    inline const vk::detail::DispatchLoaderDynamic &dld() const;
 
 #ifdef QMVK_APPLY_MEMORY_PROPERTIES_QUIRKS
     void applyMemoryPropertiesQuirks(vk::PhysicalDeviceMemoryProperties &props) const;
@@ -131,7 +129,7 @@ public:
 
 private:
     const shared_ptr<AbstractInstance> m_instance;
-    const vk::DispatchLoaderDynamic &m_dld;
+    const vk::detail::DispatchLoaderDynamic &m_dld;
 
     unordered_set<string> m_extensionProperties;
 
@@ -219,7 +217,7 @@ shared_ptr<AbstractInstance> PhysicalDevice::instance() const
 {
     return m_instance;
 }
-const vk::DispatchLoaderDynamic &PhysicalDevice::dld() const
+const vk::detail::DispatchLoaderDynamic &PhysicalDevice::dld() const
 {
     return m_dld;
 }
